==> hexalate_1.2.0.orig.tar.gz: hexalate-1.2.0/translations/hexalate_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <source>Abort current game?</source>
        <translation>Terminare il gioco attuale?</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selezionare la lingua dell&apos;applicazione:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Si prega di riavviare l&apos;applicazione per rendere il cambio della lingua effettivo.</translation>
    </message>
</context>
<context>
    <name>Puzzle</name>
    <message>
        <source>Success</source>
        <translation>Successo</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Scusa</translation>
    </message>
    <message>
        <source>Unable to load previous game. Starting a new game.</source>
        <translation>Non riesco ad aprire il gioco precedente. Inizia un altro gioco.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Hexalate</source>
        <translation>Hexalate</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gioco</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Settaggi</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Applicazione &amp;Lingua...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Info &amp;Qt</translation>
    </message>
    <message>
        <source>About Hexalate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A color matching game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> hexalate_1.2.2.orig.tar.gz: hexalate-1.2.2/translations/hexalate_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <source>Abort current game?</source>
        <translation>Terminare il gioco attuale?</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selezionare la lingua dell&apos;applicazione:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Si prega di riavviare l&apos;applicazione per rendere il cambio della lingua effettivo.</translation>
    </message>
</context>
<context>
    <name>Puzzle</name>
    <message>
        <source>Success</source>
        <translation>Successo</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Scusa</translation>
    </message>
    <message>
        <source>Unable to load previous game. Starting a new game.</source>
        <translation>Non riesco ad aprire il gioco precedente. Inizia un altro gioco.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Hexalate</source>
        <translation>Hexalate</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gioco</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Settaggi</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Applicazione &amp;Lingua...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Info &amp;Qt</translation>
    </message>
    <message>
        <source>About Hexalate</source>
        <translation>Informazioni su Hexalate</translation>
    </message>
    <message>
        <source>A color matching game</source>
        <translation>Un gioco di abbinamento dei colori</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Rilasciato sotto licenza &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>
